@@ -1,7 +1,7 @@
 package MooX::MethodProxyArgs;
-use 5.008001;
-use strictures 2;
-our $VERSION = '0.07';
+our $VERSION = '0.08';
+
+=encoding utf8
 
 =head1 NAME
 
@@ -40,6 +40,7 @@ information on how method proxies work.
 use Data::MethodProxy;
 
 use Moo::Role;
+use strictures 2;
 use namespace::clean;
 
 with 'MooX::BuildArgsHooks';
@@ -85,9 +86,17 @@ L<MooX::SingleArg>
 
 =back
 
-=head1 AUTHORS AND LICENSE
+=head1 SUPPORT
 
-See L<MooX::BuildArgs/AUTHORS> and L<MooX::BuildArgs/LICENSE>.
+See L<MooX::BuildArgs/SUPPORT>.
+
+=head1 AUTHORS
+
+See L<MooX::BuildArgs/AUTHORS>.
+
+=head1 LICENSE
+
+See L<MooX::BuildArgs/LICENSE>.
 
 =cut
 
